@@ -13,7 +13,7 @@ test_that("marc_leader_get_info() works", {
 
 # marc_008_get_info
 test_that("marc_008_get_info() works", {
-  expect_equal(books_serials_etc_sample[, marc_008_get_info(marc_008)][,pub_date],
+  expect_equal(books_serials_etc_sample[, marc_008_get_info(marc_008, original.pub.date=TRUE)][,pub_date],
                books_serials_etc_sample[,pubyear2])
   expect_equal(books_serials_etc_sample[, marc_008_get_info(marc_008)][,lang_code],
                books_serials_etc_sample[,language])
